@@ -14,11 +14,11 @@ Data::Org::Template - template engine that plays well with iterators
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 =head1 SYNOPSIS
@@ -72,7 +72,10 @@ sub _parse_template {
       my $piece = shift(@pieces);
       my ($type, $what) = @$piece;
       if ($type) {
-         if ($what =~ /^\./) { # 2018-09-08 section/subsection tag
+         if ($what eq '.' or $what =~ /^\.\|/) {
+            push @$template, ['?', $what];
+         }
+         elsif ($what =~ /^\./) { # 2018-09-08 section/subsection tag
             $swallow_nl = 1;
             if ($what eq '..') { # section end
                shift @stack if ($stack[0]->[0]); # Pop top of stack if it's a subsection.
